pygeodesy.fstats

Package pygeodesy :: Module fstats |
[frames] | no frames]

# Module fstats

Classes for running statistics and regressions based on pygeodesy.Fsum, precision floating point summation and accurate multiplication.

Version: 25.05.12

Classes
| _FstatsNamed (INTERNAL) Base class.
| _FstatsBase (INTERNAL) Base running stats class.
| Fcook Cook's `RunningStats` computing the running mean, median and (sample) kurtosis, skewness, variance, standard deviation and Jarque-Bera normality.
| Fwelford Welford's accumulator computing the running mean, (sample) variance and standard deviation.
| Flinear Cook's `RunningRegression` computing the running slope, intercept and correlation of a linear regression.

Variables
| __all__ = `_ALL_LAZY.fstats`